@@ -77,10 +77,10 @@ static char *help[] = {
   "--speed-percent, -sp           ", "Set replaying speed (percentage)",
   "--exec-key mod,key, -ek        ", "When pressing modifier mod and key key Xnee inserts a exec mark into the session file" , 
   "--exec-program s, -ep          ", "Program to start when replaying" , 
-  "--stop-key mod,key, -sk        ", "When pressing modifier mod and key key Xnee exits" , 
-  "--pause-key mod,key, -pk       ", "When pressing modifier mod and key key Xnee pauses its current action" , 
-  "--resume-key mod,key, -rk      ", "When pressing modifier mod and key key Xnee resumes its paused action" , 
-  "--insert-key mod,key, -ik      ", "When pressing modifier mod and key key Xnee inserts a META mark in the session file" , 
+  "--stop-key key, -sk            ", "When pressing key Xnee exits" , 
+  "--pause-key key, -pk           ", "When pressing key Xnee pauses its current action" , 
+  "--resume-key key, -rk          ", "When pressing key Xnee resumes its paused action" , 
+  "--insert-key key, -ik          ", "When pressing key Xnee inserts a META mark in the session file" , 
   "--write-settings file          ", "Writes settings to a resource file",
   "--print-settings, -ps          ", "Prints Xnee settings and waits (for <ENTER>)", 
   "--print-event-names, -pens     ", "Prints X11 event number and name ", 
@@ -93,12 +93,14 @@ static char *help[] = {
   "--print-data-names, -pdn       ", "Prints X11 data number and name ", 
   "--recorded-resolution res      ", "Resolution used when recording",
   "--replay-resolution res        ", "Resolution to use when replaying",
+  "--replay-offset x,y            ", "Add an offset to X and Y when replaying",
   "--no-resolution-adjustment     ", "Don't use resolution adjustment",
   "--no-sync, -ns                 ", "Don't use synchornisation during replay",
   "--feedback-xosd, -fx           ", "Use xosd to feedback",
   "--feedback-stderr, -fs         ", "Use stderr to feedback",
   "--feedback-none, -fn           ", "Dont' use feedback",
   "--manpage                      ", "Prints Xnee help text in format as used when generating man page", 
+  "--infopage                     ", "Prints Xnee help text in format as used when generating info page", 
   "--distribute, -di <LIST>       ", "Distribute recorded or replayed events to LIST where LIST is comma separated list of displays",
   "--device-event-range, -devera  <X_LIST> ", "Set device event range to X_LIST", 
   "--delivered-event-range, -devra    <X_LIST>", "Set delivered event range to X_LIST", 
@@ -139,7 +141,7 @@ static char *examples[] = {
 
 
 static char *description[] = {
-  "  " PACKAGE " can record and replay an X session." PACKAGE " also has the ability to ",
+  "  " XNEE_CLI " (part of the " PACKAGE " project) can record and replay an X session. " XNEE_CLI " also has the ability to ",
   "  distribute events to multiple displays.\n",
   NULL 
 };
@@ -245,6 +247,25 @@ xnee_parse_args (xnee_data* xd , int argc, char **argv )
 			 xnee_get_rep_resolution_y(xd)));
  	  continue;
 	}
+      else if (xnee_check (argv[i], "--replay-offset", "-rr"  ) )
+	{
+	  if (++i >= argc) 
+	    {
+	      xnee_usage(stderr);
+	      xnee_close_down(xd);
+	      exit(XNEE_WRONG_PARAMS);
+	    }
+	  if ( xnee_set_replay_offset_str (xd, argv[i]))
+	    {
+	      xnee_verbose ((xd, "failed to set replay x_offset\n"));
+	      xnee_close_down(xd);
+	      exit(XNEE_BAD_OFFSET );
+	    }
+	  xnee_verbose ((xd, "replay offset= %dx%d\n", 
+			 xnee_get_replay_offset_x(xd),
+			 xnee_get_replay_offset_y(xd)));
+ 	  continue;
+	}
       else if (xnee_check (argv[i], "--max-threshold", "-map"  ) )
 	{
 	  if (++i >= argc) 
@@ -563,6 +584,11 @@ xnee_parse_args (xnee_data* xd , int argc, char **argv )
 	  xnee_manpage (stdout);
 	  exit(XNEE_OK);
 	}
+      else if(xnee_check(argv[i], "--infopage", "--infopage")) 
+	{
+	  xnee_infopage (stdout);
+	  exit(XNEE_OK);
+	}
       else if(xnee_check(argv[i], "--help", "-h")) 
 	{
 	  xnee_usage (stdout);
@@ -873,7 +899,7 @@ xnee_usage (FILE *fd)
   char *command;
   char *descr;
 
-  fprintf (fd ,"USAGE: %s [OPTIONS]\n", PACKAGE );
+  fprintf (fd ,"USAGE: %s [OPTIONS]\n", XNEE_CLI );
   fprintf (fd ,"\n");
   fprintf (fd ,"DESCRIPTION\n");
   
@@ -936,7 +962,7 @@ xnee_manpage (FILE *fd)
   char *command;
   char *descr;
 
-  fprintf (fd ,".\\\" Copyright Henrik Sandklef 2002.\n");
+  fprintf (fd ,".\\\" Copyright Henrik Sandklef 2002, 2003, 2004, 2005, 2006\n");
   fprintf (fd ,".\\\"   \n");
   fprintf (fd ,".\\\" This file may be copied under the conditions described \n");
   fprintf (fd ,".\\\" in the LDP GENERAL PUBLIC LICENSE, Version 1, September 1998 \n");
@@ -1009,7 +1035,7 @@ xnee_manpage (FILE *fd)
   fprintf (fd ,"not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n");
 
   fprintf (fd ,".SH \"SEE ALSO\"\n"); 
-  fprintf (fd ,".BR xev (1)\n");
+  fprintf (fd ,".BR xnee(info), xev (1)\n");
 
   fprintf (fd ,".SH \"VERSION\"\n");
   fprintf (fd ,PACKAGE " man page, version " VERSION "\n");
@@ -1020,6 +1046,116 @@ xnee_manpage (FILE *fd)
   fprintf (fd ,"Mail corrections and additions to %s\n", XNEE_BUG_MAIL );
 }
 
+/**************************************************************
+ *                                                            *
+ * xnee_infopage                                              *
+ *                                                            *
+ *                                                            *
+ **************************************************************/
+void 
+xnee_infopage (FILE *fd)
+{
+  char **cpp;
+  char *command;
+  char *descr;
+
+  fprintf (fd ,"\\input texinfo  @c -*- Texinfo -*-\n");
+
+  fprintf (fd ,"@c %**start of header\n");
+  fprintf (fd ,"@setfilename "XNEE_CLI".info\n");
+  fprintf (fd ," @set EDITION %s\n", VERSION);
+  fprintf (fd ," @set VERSION %s\n", VERSION);
+  fprintf (fd ,"@settitle " XNEE_CLI " Manual \n");
+  fprintf (fd ,"@setchapternewpage off\n");
+  fprintf (fd ,"@c %**end o\n");
+
+
+
+  fprintf (fd, "@ifinfo\n");
+  fprintf (fd, "@node Top, Options,, (dir)\n");
+  fprintf (fd, "@top \n");
+/*   fprintf (fd, "@include xnee_copying\n"); */
+  fprintf (fd, "@end ifinfo\n");
+
+
+  for (cpp = description; *cpp; cpp++) 
+    {
+      fprintf (fd, "%s\n", *cpp);
+    }
+  fprintf (fd, "Current version of " PACKAGE " is " VERSION "\n");
+
+
+
+  fprintf (fd, "@menu\n");
+  fprintf (fd, "* Options::        Options\n");
+  fprintf (fd, "* Examples::       Examples\n");
+  fprintf (fd, "* Bugs::           Bugs\n");
+  fprintf (fd, "* See also::       See also\n");
+  fprintf (fd, "@end menu\n");
+
+  fprintf (fd, "@contents\n");
+  fprintf (fd, "\n");
+  fprintf (fd ,"Copyright (C) 2002, 2003, 2004, 2005, 2006 Henrik Sandklef.\n");
+  fprintf (fd, "@*\n");
+  fprintf (fd, "@*\n");
+  fprintf (fd ,"This  is  free  software;  see the source for copying conditions. ");
+  fprintf (fd ,"There is NO warranty;");
+  fprintf (fd ,"not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n");
+
+
+  fprintf (fd, "@node Options, Examples, top, top \n");
+
+  for (cpp = help; *cpp; cpp++) 
+    {
+      fprintf (fd, "@code{  %s}\n", *cpp++);
+      fprintf (fd, "%s\n\n", *cpp);
+    }
+
+  for (cpp = explain; *cpp; cpp++) 
+    {
+      fprintf (fd, "%s\n", *cpp++);
+      fprintf (fd, "\t%s\n", *cpp);
+    }
+
+
+  fprintf (fd, "@node Examples, Bugs, Options, top \n");
+  for (cpp = examples; *cpp; cpp++) 
+    {
+      command=*cpp++;
+      descr=*cpp;
+      if (command != NULL )
+	{
+	  if (descr != NULL )
+	    fprintf (fd, "  %s\n", command);
+	  else
+	    {
+	      fprintf (fd, "  %s\n", command);
+	      break;
+	    }
+	  
+	  if (descr!=NULL)
+	    fprintf (fd, "\t%s\n\n", *cpp);
+	}
+    }
+  fprintf (fd ,"\n");
+
+  fprintf (fd, "@node Bugs, See also, Examples,top \n");
+  fprintf (fd, "If you envounter a bug, report it to ");
+  fprintf (fd, "@indent @ @ @ @email{xnee-bug@@gnu.org}\n@ \n");
+  fprintf (fd, "@indent or go to the Xnee site:\n");
+  fprintf (fd, "@indent @ @ @ @url{http://svannah.gnu.org}\n@\n");
+  fprintf (fd, "@indent Before reporting the bug, make sure it is not already reported\n");
+
+  fprintf (fd, "@node See also, (dir), Bugs,top \n");
+  fprintf (fd ,"There are some other interesting programs out there\n@*\n@*\n");
+  fprintf (fd ,"Look at xev (1)\n@*\n");
+  fprintf (fd ,"Also make sure to read the Xnee manual or info page\n");
+
+
+  fprintf (fd, "@bye\n");
+  return;
+}
+
 int
 xnee_type_help (xnee_data *xd)
 {
