@@ -26,6 +26,11 @@ Foundation, Inc., 51 Franklin Street, Boston, MA  02110-1301, USA.
 #ifndef XNEE_PRINT_H
 #define XNEE_PRINT_H
 
+#define XNEE_VERBOSE_ENTER_FUNCTION() xnee_verbose((xd, " ---> %s\n", __func__ ))
+#define XNEE_VERBOSE_LEAVE_FUNCTION() xnee_verbose((xd, " <--- %s\n", __func__ ))
+#define XNEE_VERBOSE_IN_FUNCTION(str) xnee_verbose((xd, "      %s: \"%s\"\n", __func__ , str))
+
+
 /**
  * Prints number and name of X11 events
  *
