@@ -463,6 +463,14 @@ xnee_print_sys_info(xnee_data *xd, FILE *out)
 	  timeinfo->tm_hour, 
 	   timeinfo->tm_min , 
 	   timeinfo->tm_sec  );
+  if ( xd->program_name!=NULL)
+    {
+      fprintf (out, "# Xnee program:           %s \n", xd->program_name);
+    }
+  else
+    {
+      fprintf (out, "# Xnee program:           <missing info> \n");
+    }
   fprintf (out, "# Xnee version:           %s \n", VERSION);
   fprintf (out, "# Xnee home:              %s \n", XNEE_HOME_URL);
   fprintf (out, "# Xnee info mailing list: %s \n", XNEE_MAIL);
@@ -926,22 +934,22 @@ xnee_print_xnee_settings (xnee_data* xd, /*@null@*/ FILE* out)
   fprintf (out,  "##############################################\n");
   fprintf (out,  "#      Key Grabs                             #\n");
   fprintf (out,  "##############################################\n");
-  fprintf (out,  "%s         %s\n",
+  fprintf (out,  "# %s         %s\n",
 	   XNEE_STOP_KEY,  
 	   (xd->grab_keys->action_keys[XNEE_GRAB_STOP].str) ? xd->grab_keys->action_keys[XNEE_GRAB_STOP].str: "0" );
-  fprintf (out,   "%s        %s\n",
+  fprintf (out,   "# %s        %s\n",
 	   XNEE_PAUSE_KEY,
 	   (xd->grab_keys->action_keys[XNEE_GRAB_PAUSE].str) ? xd->grab_keys->action_keys[XNEE_GRAB_PAUSE].str: "0" );
-  fprintf (out,   "%s       %s\n",
+  fprintf (out,   "# %s       %s\n",
 	   XNEE_RESUME_KEY,
 	   (xd->grab_keys->action_keys[XNEE_GRAB_RESUME].str) ? xd->grab_keys->action_keys[XNEE_GRAB_RESUME].str: "0" );
-  fprintf (out,   "%s       %s\n",
+  fprintf (out,   "# %s       %s\n",
 	   XNEE_INSERT_KEY,
 	   (xd->grab_keys->action_keys[XNEE_GRAB_INSERT].str) ? xd->grab_keys->action_keys[XNEE_GRAB_INSERT].str: "0" );
-  fprintf (out,   "%s         %s\n",
+  fprintf (out,   "# %s         %s\n",
 	   XNEE_EXEC_KEY,
 	   (xd->grab_keys->action_keys[XNEE_GRAB_EXEC].str) ? xd->grab_keys->action_keys[XNEE_GRAB_EXEC].str: "0" );
-  fprintf (out,   "%s         %s\n",
+  fprintf (out,   "# %s         %s\n",
 	   XNEE_EXEC_PROGRAM,
 	   (xd->grab_keys->action_keys[XNEE_GRAB_EXEC].extra_str) 
 	   ? xd->grab_keys->action_keys[XNEE_GRAB_EXEC].extra_str: XNEE_EXEC_NO_PROG );
