@@ -3,7 +3,8 @@
  *                                                                   
  * Xnee enables recording and replaying of X protocol data           
  *                                                                   
- *        Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004 Henrik Sandklef 
+ *        Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+                        Henrik Sandklef 
  *                                                                   
  * This program is free software; you can redistribute it and/or     
  * modify it under the terms of the GNU General Public License       
@@ -90,6 +91,13 @@ xnee_start(xnee_data *xd)
 {
    int ret ;
 
+   if (xd==NULL)
+     {
+       return XNEE_NO_MAIN_DATA;
+     }
+
+   xd->in_use = 1;
+
 
    /* grab all keys that have been specified */
    ret = xnee_grab_all_keys (xd);
